@@ -167,7 +167,7 @@ namespace Oxygen
                 break;
             }
 
-            case Qt::MidButton:
+            case Qt::MiddleButton:
             {
                 hide();
                 break;
